//smokeNade.cs
datablock AudioProfile(smokeNadeBounceSound)
{
   filename    = "./smokeNadeBounce.wav";
   description = AudioDefault3d;
   preload = true;
};

datablock ParticleData(smokeNadeParticle)
{
	dragCoefficient		= 1.0;
	windCoefficient		= 1.0;
	gravityCoefficient	= -0.3;
	inheritedVelFactor	= 0.0;
	constantAcceleration	= 0.0;
	lifetimeMS		= 10000;
	lifetimeVarianceMS	= 500;
	spinSpeed		= 10.0;
	spinRandomMin		= -10.0;
	spinRandomMax		= 10.0;
	useInvAlpha		= true;
	animateTexture		= false;
	//framesPerSec		= 1;

	textureName		= "./Darkcloud";
	//animTexName		= "~/data/particles/cloud";

	// Interpolation variables
	colors[0]	= "0 0.6 0 0.95";
	colors[1]	= "0 0.9 0 0.1";

	sizes[0]	= 0.1;
	sizes[1]	= 6.0;

	times[0]	= 0;
	times[1]	= 1;
};

datablock ParticleEmitterData(smokeNadeEmitter)
{
   ejectionPeriodMS = 20;
   periodVarianceMS = 5;
   ejectionVelocity = 4;
   velocityVariance = 2;
   ejectionOffset   = 0;
   thetaMin         = 0;
   thetaMax         = 45;
   phiReferenceVel  = 0;
   phiVariance      = 90;
   overrideAdvance = false;
   particles = "smokeNadeParticle";
   uiName = "Smoke Signal";
};

//projectile
datablock ProjectileData(smokeNadeProjectile)
{
   projectileShapeName = "./smokeNadeProjectile.dts";
   directDamage        = 2;
   directDamageType  = $DamageType::RocketDirect;
   radiusDamageType  = $DamageType::RocketRadius;
   impactImpulse	   = 200;
   verticalImpulse	   = 200;
   particleEmitter     = smokeNadeEmitter;

   muzzleVelocity      = 30;
   velInheritFactor    = 0;

   armingDelay         = 14000; 
   lifetime            = 14000;
   fadeDelay           = 20000;
   bounceElasticity    = 0.4;
   bounceFriction      = 0.9;
   isBallistic         = true;
   gravityMod = 1.0;
   explodeOnDeath = true;

   hasLight    = false;
};


//////////
// item //
//////////
datablock ItemData(smokeNadeItem)
{
	category = "Item";  // Mission editor category

	 // Basic Item Properties
	shapeFile = "./smokeNade.dts";
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Smoke Signal";
	iconName = "./icon_smokeNade";
	doColorShift = false;
	colorShiftColor = "0.400 0.196 0 1.000";

	 // Dynamic properties defined by the scripts
	image = smokeNadeImage;
	canDrop = true;
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(smokeNadeImage)
{
   // Basic Item properties
   shapeFile = "./smokeNade.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";
   //eyeOffset = "0.1 0.2 -0.55";

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this weapon doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = true;

   // Add the WeaponImage namespace as a parent, WeaponImage namespace
   // provides some hooks into the inventory system.
   className = "WeaponImage";

   // Projectile && Ammo.
   item = smokeNadeItem;
   ammo = " ";
   projectile = smokeNadeProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = false;
   //raise your arm up or not
   armReady = true;

   //casing = " ";
   doColorShift = false;
   colorShiftColor = "0.400 0.196 0 1.000";

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]			= "Activate";
	stateTimeoutValue[0]		= 0.1;
	stateTransitionOnTimeout[0]	= "Ready";
	stateSequence[0]		= "ready";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]			= "Ready";
	stateTransitionOnTriggerDown[1]	= "Charge";
	stateAllowImageChange[1]	= true;

	stateName[2]                    = "Charge";
	stateTransitionOnTimeout[2]	= "Armed";
	stateTimeoutValue[2]            = 0.7;
	stateWaitForTimeout[2]		= false;
	stateTransitionOnTriggerUp[2]	= "AbortCharge";
	stateScript[2]                  = "onCharge";
	stateAllowImageChange[2]        = false;
	
	stateName[3]			= "AbortCharge";
	stateTransitionOnTimeout[3]	= "Ready";
	stateTimeoutValue[3]		= 0.3;
	stateWaitForTimeout[3]		= true;
	stateScript[3]			= "onAbortCharge";
	stateAllowImageChange[3]	= false;

	stateName[4]			= "Armed";
	stateTransitionOnTriggerUp[4]	= "Fire";
	stateAllowImageChange[4]	= false;

	stateName[5]			= "Fire";
	stateTransitionOnTimeout[5]	= "Done";
	stateTimeoutValue[5]		= 0.5;
	stateFire[5]			= true;
	stateSequence[5]		= "fire";
	stateScript[5]			= "onFire";
	stateWaitForTimeout[5]		= true;
	stateAllowImageChange[5]	= false;

	stateName[6]					= "Done";
	stateScript[6]					= "onDone";

};

package smokeNadePackage
{
	function Armor::onCollision(%this, %obj, %col, %a, %b, %c, %d, %e, %f)
	{
		if(%col.dataBlock $= "smokeNadeItem" && %col.canPickup)
		{
			for(%i=0;%i<%this.maxTools;%i++)
			{
				%item = %obj.tool[%i];
				if(%item $= 0 || %item $= "")
				{
					%freeSlot = 1;
					break;
				}
			}

			if(%freeSlot)
			{
				%obj.pickup(%col);
				return;
			}
		}
		Parent::onCollision(%this, %obj, %col, %a, %b, %c, %d, %e, %f);
	}
};
activatePackage(smokeNadePackage);

function smokeNadeImage::onCharge(%this, %obj, %slot)
{
	%obj.playthread(2, spearReady);
	%obj.lastHESlot = %obj.currTool;
}

function smokeNadeImage::onAbortCharge(%this, %obj, %slot)
{
	%obj.playthread(2, root);
}

function smokeNadeImage::onFire(%this, %obj, %slot)
{
	%obj.playthread(2, spearThrow);
	Parent::OnFire(%this, %obj, %slot);

	%currSlot = %obj.lastHESlot;
	%obj.tool[%currSlot] = 0;
	%obj.weaponCount--;
	messageClient(%obj.client,'MsgItemPickup','',%currSlot,0);
	serverCmdUnUseTool(%obj.client);
}

function smokeNadeImage::onDone(%this,%obj,%slot)
{
	%obj.unMountImage(%slot);
}

function smokeNadeProjectile::onCollision(%this,%obj,%col,%fade,%pos,%normal)
{
	serverPlay3D(smokeNadeBounceSound,%obj.getTransform());
}